==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/catnip/levelWrappers/WrappedServerLevel.java <==
package com.zurrtum.create.catnip.levelWrappers;

import org.jetbrains.annotations.Nullable;

import java.util.Collections;
import java.util.List;
import net.minecraft.class_1297;
import net.minecraft.class_156;
import net.minecraft.class_1863;
import net.minecraft.class_1953;
import net.minecraft.class_1959;
import net.minecraft.class_22;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3414;
import net.minecraft.class_3419;
import net.minecraft.class_3611;
import net.minecraft.class_5268;
import net.minecraft.class_5363;
import net.minecraft.class_6880;
import net.minecraft.class_9209;

public class WrappedServerLevel extends class_3218 {
    protected class_3218 level;

    public WrappedServerLevel(class_3218 level) {
        super(
            level.method_8503(),
            class_156.method_18349(),
            level.method_8503().field_23784,
            (class_5268) level.method_8401(),
            level.method_27983(),
            new class_5363(level.method_40134(), level.method_14178().method_12129()),
            level.method_27982(),
            level.method_22385().field_20641,
            Collections.emptyList(),
            false,
            level.method_52168()
        );
        this.level = level;
    }

    @Override
    public int method_22339(class_2338 pos) {
        return 15;
    }

    @Override
    public void method_8413(class_2338 pos, class_2680 oldState, class_2680 newState, int flags) {
        level.method_8413(pos, oldState, newState, flags);
    }

    @Override
    public void method_64310(class_2338 pos, class_2248 block, int delay) {
    }

    @Override
    public void method_64312(class_2338 pos, class_3611 fluid, int delay) {
    }

    @Override
    public void method_64311(class_2338 pos, class_2248 block, int delay, class_1953 priority) {
    }

    @Override
    public void method_64313(class_2338 pos, class_3611 fluid, int delay, class_1953 priority) {
    }

    @Override
    public void method_8444(@Nullable class_1297 source, int eventId, class_2338 pos, int data) {
    }

    @Override
    public List<class_3222> method_18456() {
        return Collections.emptyList();
    }

    @Override
    public void method_43128(@Nullable class_1297 source, double x, double y, double z, class_3414 sound, class_3419 category, float volume, float pitch) {
    }

    @Override
    public void method_43129(@Nullable class_1297 source, class_1297 entity, class_3414 sound, class_3419 category, float volume, float pitch) {
    }

    @Override
    public @Nullable class_1297 method_8469(int id) {
        return null;
    }

    @Override
    public @Nullable class_22 method_17891(class_9209 id) {
        return null;
    }

    @Override
    public boolean method_8649(class_1297 entity) {
        entity.method_51502(level);
        return level.method_8649(entity);
    }

    @Override
    public void method_17890(class_9209 id, class_22 state) {
    }

    @Override
    public class_9209 method_17889() {
        return new class_9209(0);
    }

    @Override
    public void method_8517(int entityId, class_2338 pos, int progress) {
    }

    @Override
    public class_1863 method_8433() {
        return level.method_64577();
    }

    @Override
    public class_6880<class_1959> method_22387(int biomeX, int biomeY, int biomeZ) {
        return level.method_22387(biomeX, biomeY, biomeZ);
    }
}

==> create-fly-6.0.8-1.21.10-2-sources.jar: com/zurrtum/create/catnip/levelWrappers/WrappedServerLevel.java <==
package com.zurrtum.create.catnip.levelWrappers;

import org.jetbrains.annotations.Nullable;

import java.util.Collections;
import java.util.List;
import net.minecraft.class_1297;
import net.minecraft.class_156;
import net.minecraft.class_1863;
import net.minecraft.class_1953;
import net.minecraft.class_1959;
import net.minecraft.class_22;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3414;
import net.minecraft.class_3419;
import net.minecraft.class_3611;
import net.minecraft.class_5268;
import net.minecraft.class_5363;
import net.minecraft.class_6880;
import net.minecraft.class_9209;

public class WrappedServerLevel extends class_3218 {
    protected class_3218 level;

    public WrappedServerLevel(class_3218 level) {
        super(
            level.method_8503(),
            class_156.method_18349(),
            level.method_8503().field_23784,
            (class_5268) level.method_8401(),
            level.method_27983(),
            new class_5363(level.method_40134(), level.method_14178().method_12129()),
            level.method_27982(),
            level.method_22385().field_20641,
            Collections.emptyList(),
            false,
            level.method_52168()
        );
        this.level = level;
    }

    @Override
    public float method_8442(float tickProgress) {
        return 0;
    }

    @Override
    public int method_22339(class_2338 pos) {
        return 15;
    }

    @Override
    public void method_8413(class_2338 pos, class_2680 oldState, class_2680 newState, int flags) {
        level.method_8413(pos, oldState, newState, flags);
    }

    @Override
    public void method_64310(class_2338 pos, class_2248 block, int delay) {
    }

    @Override
    public void method_64312(class_2338 pos, class_3611 fluid, int delay) {
    }

    @Override
    public void method_64311(class_2338 pos, class_2248 block, int delay, class_1953 priority) {
    }

    @Override
    public void method_64313(class_2338 pos, class_3611 fluid, int delay, class_1953 priority) {
    }

    @Override
    public void method_8444(@Nullable class_1297 source, int eventId, class_2338 pos, int data) {
    }

    @Override
    public List<class_3222> method_18456() {
        return Collections.emptyList();
    }

    @Override
    public void method_43128(
        @Nullable class_1297 source,
        double x,
        double y,
        double z,
        class_3414 sound,
        class_3419 category,
        float volume,
        float pitch
    ) {
    }

    @Override
    public void method_43129(@Nullable class_1297 source, class_1297 entity, class_3414 sound, class_3419 category, float volume, float pitch) {
    }

    @Override
    public @Nullable class_1297 method_8469(int id) {
        return null;
    }

    @Override
    public @Nullable class_22 method_17891(class_9209 id) {
        return null;
    }

    @Override
    public boolean method_8649(class_1297 entity) {
        entity.method_51502(level);
        return level.method_8649(entity);
    }

    @Override
    public void method_17890(class_9209 id, class_22 state) {
    }

    @Override
    public class_9209 method_17889() {
        return new class_9209(0);
    }

    @Override
    public void method_8517(int entityId, class_2338 pos, int progress) {
    }

    @Override
    public class_1863 method_8433() {
        return level.method_64577();
    }

    @Override
    public class_6880<class_1959> method_22387(int biomeX, int biomeY, int biomeZ) {
        return level.method_22387(biomeX, biomeY, biomeZ);
    }
}
